try:
    from setuptools import setup
except ImportError:
    from disutils.core import setup

config = {
    'description': 'this be a simplez testeroozz',
    'author': 'ilja',
    'author_email': 'testeroozz@gmail.com',
    'version': '0.1',
    'install_requires': ['nose'],
    'packages': ['testeroozz'],
    'scripts': [],
    'name': 'testeroozz'
}

setup(**config)



"""This is a simplez testeroozz module. Does naffin useful."""

import random

def great_summation(first, second):
    print("let's play a game")
    print("give me two numbers ill give you their sum")
    # first = input("first number: ")
    # second = input("second number: ")
    print(random.randint(1, 100))
    print("fuck you.")
